****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_qrpe_createpov1.sas  
*
* Created (mm/dd/yyyy): 02/01/2018
* Last modified: 
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*	This program will find all potential encounters with exposure and create the POV1 dataset 
*
*  Program inputs:                                                                                   
*	-Dataset with claims defined as being potential exposures   
* 
*  Program outputs:                                                                                                                                       
* 	-Dataset with all potential exposures (POV1)
* 
* PARAMETERS:
*
*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%macro ms_qrpe_createpov1();

%put =====> MACRO CALLED: ms_qrpe_createpov1 v1.0;

	*Find list of all potential exposure encounters;

		*delete duplicate encounters;
		proc sort data=_groupindex(drop=adate expiredt code codetype codecat) nodupkey out=_pov1;
			by patid encounterID;
		run;

	/****************/
	/* Demographics */
	/****************/

	proc sort nodupkey data=_POV1 out=_uniquepts(keep=PatId);
		by PatId;
	run;

	*Age and demogs;		
    proc sql noprint;        
		create table _DemoCount as
        select dem.PatId, 
			   Count(dem.PatId) as numdemo
        from indata.&demtable as dem 
             inner join 
             _UniquePts as pts
        on dem.patid = pts.patid
		group by dem.PatId;

		create table _demo as
        select distinct pts.*, 
                        birth_date, 
                      	case when sex = 'F' then 'F'
							 when sex = 'M' then 'M'
							 else 'O'						
						end as sex,
                        race,
						hispanic,
                        (enc_start-birth_date)/365.25 as Age
        from indata.&demtable as dem 
             inner join _POV1 as pts			 
        on dem.patid = pts.patid
			 inner join _demoCount (where=(numdemo=1)) as cnt
		on cnt.patid = pts.patid;

		create table _POV1
		as select * 
		from _demo;        
    quit;

    *CALCULATE AGE STRATA;
    %ms_agestrat(infile=_POV1,
                 outfile=_POV1,
                 startdt=birth_date,
                 enddt=enc_start,
                 timestrat=&agestrat.);

	data _POV1;
   	 	set _POV1;
		if strip(AgeGroup) ne "";
	run;

%put NOTE: ********END OF MACRO: ms_qrpe_createpov1 v1.0********;

%mend ms_qrpe_createpov1;
